@@ -20,12 +20,12 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.27_09';
-use English qw( -no_match_vars ); # Avoids reg-ex performance penalty
+our $VERSION = '0.27_11';
+use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
 use Cwd qw(cwd);
-use Data::Printer { caller_info => 1, colored => 1, };
+use Data::Printer {caller_info => 1, colored => 1,};
 use File::Find qw(find);
 use File::Spec;
 use List::MoreUtils qw(firstidx);
@@ -37,7 +37,7 @@ use Scalar::Util qw(looks_like_number);
 use Term::ANSIColor qw( :constants colored colorstrip );
 use Try::Tiny;
 
-use constant { BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3, };
+use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
 use version;
 
 # stop rlib from Fing all over cwd
@@ -55,30 +55,32 @@ sub run {
 	try {
 		$self->first_package_name();
 	};
+
 #	$self->output_header();
 
 	$self->find_required_modules();
+
 #	$self->find_required_test_modules();
 
-	p $self->{modules} if ( $self->verbose == TWO );
+	p $self->{modules} if ($self->verbose == TWO);
 
-	$self->remove_noisy_children( $self->{package_requires} )
+	$self->remove_noisy_children($self->{package_requires})
 		if $self->experimental;
-	$self->remove_twins( $self->{package_requires} ) if $self->experimental;
+	$self->remove_twins($self->{package_requires}) if $self->experimental;
 
 
-	# Run a second time if we found any twins, this will sort out twins and triplets etc
-	$self->remove_noisy_children( $self->{package_requires} )
+# Run a second time if we found any twins, this will sort out twins and triplets etc
+	$self->remove_noisy_children($self->{package_requires})
 		if $self->found_twins;
 
 	$self->find_required_test_modules();
 
 	# Now we have switched to MetaCPAN-Api we can hunt for noisy children in test requires
-	if ( $self->experimental ) {
+	if ($self->experimental) {
 		p $self->{test_requires} if $self->debug;
-		$self->remove_noisy_children( $self->{test_requires} );
-		foreach my $module ( keys %{ $self->{test_requires} } ) {
-			if ( $self->{package_requires}{$module} ) {
+		$self->remove_noisy_children($self->{test_requires});
+		foreach my $module (keys %{$self->{test_requires}}) {
+			if ($self->{package_requires}{$module}) {
 				warn $module if $self->debug;
 				try {
 					delete $self->{test_requires}{$module};
@@ -87,34 +89,24 @@ sub run {
 		}
 		p $self->{test_requires} if $self->debug;
 
-## ToDo look at resolving noisy children across types found
-#		p $self->{recommends} if $self->debug;
-#		$self->remove_noisy_children( $self->{recommends} );
-#		foreach my $module ( keys %{ $self->{recommends} } ) {
-#			if ( $self->{package_requires}{$module} ) {
-#				warn $module if $self->debug;
-#				try {
-#					delete $self->{recommends}{$module};
-#				};
-#			}
-#		}
-#		p $self->{recommends} if $self->debug;
-
-
 	}
 
-	# display chosen output format 
+	# display chosen output format
 	$self->output_header();
 
-	$self->output_main_body( 'requires',      $self->{package_requires} );
-	$self->output_main_body( 'test_requires', $self->{test_requires} );
-	$self->output_main_body( 'recommends',    $self->{recommends} );
-	$self->output_main_body( 'test_develop',  $self->{test_develop} )
+	$self->output_main_body('requires',      $self->{package_requires});
+			if ($self->format =~ /cpanfile|metajson/) {
+				$self->output_main_body('runtime_recommends', $self->{runtime_recommends});
+			}
+
+	$self->output_main_body('test_requires', $self->{test_requires});
+	$self->output_main_body('recommends',    $self->{recommends});
+	$self->output_main_body('test_develop',  $self->{test_develop})
 		if $self->develop;
 
 	$self->output_footer();
 
-#	p $self->{modules};
+	p $self->{modules} if $self->debug;
 
 	return;
 }
@@ -125,7 +117,7 @@ sub run {
 sub _initialise {
 	my $self = shift;
 
-	# let's give Output a copy, to stop it being Fup as well suspect Tiny::Path as-well
+# let's give Output a copy, to stop it being F'up as well, suspect Tiny::Path as-well rlib
 	warn 'working in dir: ' . $Working_Dir if $self->debug;
 
 	return;
@@ -140,7 +132,7 @@ sub first_package_name {
 	try {
 		find(
 			sub { _find_package_names($self); },
-			File::Spec->catfile( $Working_Dir, 'lib' )
+			File::Spec->catfile($Working_Dir, 'lib')
 		);
 	};
 
@@ -149,16 +141,19 @@ sub first_package_name {
 	# We will assume the first package found is our Package Name, pot lock :)
 	# due to Milla not being a dist we go and get dist-name
 	try {
-		my $mcpan_module_info = $self->mcpan->module( $self->package_names->[0] );
+		my $mcpan_module_info = $self->mcpan->module($self->package_names->[0]);
 		my $distribution_name = $mcpan_module_info->{distribution};
 		$distribution_name =~ s{-}{::}g;
 		$self->_set_distribution_name($distribution_name);
 	}
 	catch {
-		$self->_set_distribution_name( $self->package_names->[0] );
+		$self->_set_distribution_name($self->package_names->[0]);
 	};
+
 	# I still want to see package name even though infile sets verbose = 0
-	say 'Package: ' . $self->distribution_name if $self->verbose or $self->format eq 'infile';
+	say 'Package: ' . $self->distribution_name
+		if $self->verbose
+		or $self->format eq 'infile';
 
 	return;
 }
@@ -169,7 +164,7 @@ sub _find_package_names {
 	my $self     = shift;
 	my $filename = $_;
 	state $files_checked;
-	if ( defined $files_checked ) {
+	if (defined $files_checked) {
 		return if $files_checked >= THREE and not $self->min_ver_fast;
 	}
 
@@ -177,22 +172,24 @@ sub _find_package_names {
 	return if $filename !~ /[.]pm$/sxm;
 
 	# Load a Document from a file
-	$self->_set_ppi_document( PPI::Document->new($filename) );
+	$self->_set_ppi_document(PPI::Document->new($filename));
 
 	try {
-		if ( $self->min_ver_fast ) {
+		if ($self->min_ver_fast) {
 
 			# say 'running fast';
 			$self->min_version($filename);
-		} else {
+		}
+		else {
 
 			# say 'running slow';
-			$self->min_version(); # if not $self->min_ver_fast;
+			$self->min_version();    # if not $self->min_ver_fast;
 		}
 	};
 
 	# Extract package names
-	push @{ $self->package_names }, $self->ppi_document->find_first('PPI::Statement::Package')->namespace;
+	push @{$self->package_names},
+		$self->ppi_document->find_first('PPI::Statement::Package')->namespace;
 	$files_checked++;
 
 	return;
@@ -205,18 +202,19 @@ sub _find_package_names {
 sub find_required_modules {
 	my $self = shift;
 
-	my @posiable_directories_to_search = map { File::Spec->catfile( $Working_Dir, $_ ) } qw( script bin lib );
+	my @posiable_directories_to_search
+		= map { File::Spec->catfile($Working_Dir, $_) } qw( script bin lib );
 
 	my @directories_to_search = ();
 	foreach my $directory (@posiable_directories_to_search) {
-		if ( defined -d $directory ) {
+		if (defined -d $directory) {
 			push @directories_to_search, $directory;
 		}
 	}
 	p @directories_to_search if $self->debug;
 
 	try {
-		find( sub { _find_makefile_requires($self); }, @directories_to_search );
+		find(sub { _find_makefile_requires($self); }, @directories_to_search);
 	};
 
 	return;
@@ -230,25 +228,26 @@ sub find_required_test_modules {
 
 	# By default we shell only check t\ (to xt\ or not?)
 	my @posiable_directories_to_search;
-	if ( not $self->experimental ) {
-		@posiable_directories_to_search = map { File::Spec->catfile( $Working_Dir, $_ ) } qw( t );
-	} else {
-		@posiable_directories_to_search = map { File::Spec->catfile( $Working_Dir, $_ ) } qw( t xt );
+	if (not $self->experimental) {
+		@posiable_directories_to_search
+			= map { File::Spec->catfile($Working_Dir, $_) } qw( t );
+	}
+	else {
+		@posiable_directories_to_search
+			= map { File::Spec->catfile($Working_Dir, $_) } qw( t xt );
 	}
 
 	my @directories_to_search = ();
 	foreach my $directory (@posiable_directories_to_search) {
-		if ( defined -d $directory ) {
+		if (defined -d $directory) {
 			push @directories_to_search, $directory;
 		}
 	}
 
 	try {
 		foreach my $directorie (@directories_to_search) {
-			find(
-				sub { _find_makefile_test_requires( $self, $directorie ); },
-				$directorie
-			);
+			find(sub { _find_makefile_test_requires($self, $directorie); },
+				$directorie);
 		}
 	};
 
@@ -260,8 +259,8 @@ sub find_required_test_modules {
 # _find_makefile_requires
 #######
 sub _find_makefile_requires {
-	my $self     = shift;
-	my $filename = $_;
+	my $self      = shift;
+	my $filename  = $_;
 	my $is_script = 0;
 
 	given ($filename) {
@@ -280,37 +279,36 @@ sub _find_makefile_requires {
 		default { return if not $self->_is_perlfile($filename); $is_script = 1; }
 	}
 	try {
-		if ( $self->min_ver_fast ) {
+		if ($self->min_ver_fast) {
 			$self->min_version($filename);
-		} else {
+		}
+		else {
 			$self->min_version() if $is_script;
 		}
 	};
 
 	my $relative_dir = $File::Find::dir;
 	$relative_dir =~ s/$Working_Dir//;
-	$self->_set_looking_infile( File::Spec->catfile( $relative_dir, $filename ) );
-	$self->_set_ppi_document( PPI::Document->new($filename) );
+	$self->_set_looking_infile(File::Spec->catfile($relative_dir, $filename));
+	$self->_set_ppi_document(PPI::Document->new($filename));
 
 	# do extra test early check for use_module before hand
-#	p $filename;
-	$self->xtests_use_module();
+	$self->xtests_use_module('runtime_recommends');
 
+	# ToDo add eval/try here -> prereqs { runtime { suggests or recommends {...}}}
+	$self->xtests_eval('runtime_recommends');
 
-	my $prereqs = $self->scanner->scan_ppi_document( $self->ppi_document );
+	my $prereqs = $self->scanner->scan_ppi_document($self->ppi_document);
 	my @modules = $prereqs->required_modules;
 
-# todo add eval/try here
-#	$self->_xtests_eval();
-
-
-foreach my $mod_ver ( @modules ){
-	$self->{found_version}{$mod_ver} = $prereqs->requirements_for_module($mod_ver);
-}
+	foreach my $mod_ver (@modules) {
+		$self->{found_version}{$mod_ver}
+			= $prereqs->requirements_for_module($mod_ver);
+	}
 
 	$self->{skip_not_mcpan_stamp} = 0;
 
-	if ( /^Dist::Zilla::Role::PluginBundle/ ~~ @modules ) {
+	if (/^Dist::Zilla::Role::PluginBundle/ ~~ @modules) {
 
 		$self->{skip_not_mcpan_stamp} = 1;
 
@@ -318,7 +316,7 @@ foreach my $mod_ver ( @modules ){
 		if ($ppi_tqs) {
 
 			# my @modules;
-			foreach my $include ( @{$ppi_tqs} ) {
+			foreach my $include (@{$ppi_tqs}) {
 
 				my $module = $include->content;
 				$module =~ s/^[']//;
@@ -333,7 +331,7 @@ foreach my $mod_ver ( @modules ){
 		}
 	}
 
-	$self->_process_found_modules( 'package_requires', \@modules );
+	$self->_process_found_modules('package_requires', \@modules);
 	return;
 }
 
@@ -344,7 +342,7 @@ sub _is_perlfile {
 	my $self     = shift;
 	my $filename = shift;
 
-	$self->_set_ppi_document( PPI::Document->new($filename) );
+	$self->_set_ppi_document(PPI::Document->new($filename));
 	my $ppi_tc = $self->ppi_document->find('PPI::Token::Comment');
 
 	my $a_pl_file = 0;
@@ -355,8 +353,8 @@ sub _is_perlfile {
 		$a_pl_file = 1 if $ppi_tc->[0]->content =~ m/^#!.*perl.*$/;
 	}
 
-	if ( $self->ppi_document->find('PPI::Statement::Package') || $a_pl_file ) {
-		if ( $self->verbose >= TWO ) {
+	if ($self->ppi_document->find('PPI::Statement::Package') || $a_pl_file) {
+		if ($self->verbose >= TWO) {
 
 			print "looking for requires in (package) -> "
 				if $self->ppi_document->find('PPI::Statement::Package');
@@ -365,7 +363,8 @@ sub _is_perlfile {
 			say $filename ;
 		}
 		return 1;
-	} else {
+	}
+	else {
 		return 0;
 	}
 
@@ -379,19 +378,22 @@ sub _find_makefile_test_requires {
 	my $self       = shift;
 	my $directorie = shift;
 	##p $directorie;
-	my $prerequisites = ( $directorie =~ m/xt$/ ) ? 'test_develop' : 'test_requires';
+	my $prerequisites
+		= ($directorie =~ m/xt$/) ? 'test_develop' : 'test_requires';
 	$self->_set_xtest('test_develop') if $directorie =~ m/xt$/;
 
 	my $filename = $_;
 	return if $filename !~ /[.]t|pm$/sxm;
 
 	say 'looking for test_requires in: ' . $filename if $self->verbose >= TWO;
+
 # p $filename;
 	my $relative_dir = $File::Find::dir;
 	$relative_dir =~ s/$Working_Dir//;
-	$self->_set_looking_infile( File::Spec->catfile( $relative_dir, $filename ) );
+	$self->_set_looking_infile(File::Spec->catfile($relative_dir, $filename));
+
 	# Load a Document from a file and check use and require contents
-	$self->_set_ppi_document( PPI::Document->new($filename) );
+	$self->_set_ppi_document(PPI::Document->new($filename));
 
 	# do extra test early check for Test::Requires before hand
 	$self->xtests_test_requires();
@@ -400,30 +402,33 @@ sub _find_makefile_test_requires {
 	$self->xtests_use_ok();
 
 	# do extra test early to identify eval befroe hand
-	$self->_xtests_eval();
+	$self->xtests_eval();
 
 	# do extra test early check for use_module before hand
 #	p $filename;
 	$self->xtests_use_module();
 
-	my $prereqs = $self->scanner->scan_ppi_document( $self->ppi_document );
+	my $prereqs = $self->scanner->scan_ppi_document($self->ppi_document);
 	my @modules = $prereqs->required_modules;
 
 	p @modules if $self->debug;
 
-foreach my $mod_ver ( @modules ){
-	$self->{found_version}{$mod_ver} = $prereqs->requirements_for_module($mod_ver);
-}
+	foreach my $mod_ver (@modules) {
+		$self->{found_version}{$mod_ver}
+			= $prereqs->requirements_for_module($mod_ver);
+	}
 
-	if ( scalar @modules > 0 ) {
-		if ( $self->format =~ /cpanfile|metajson/ ) {
-			if ( $self->xtest eq 'test_requires' ) {
-				$self->_process_found_modules( 'test_requires', \@modules );
-			} elsif ( $self->develop && $self->xtest eq 'test_develop' ) {
-				$self->_process_found_modules( 'test_develop', \@modules );
+	if (scalar @modules > 0) {
+		if ($self->format =~ /cpanfile|metajson/) {
+			if ($self->xtest eq 'test_requires') {
+				$self->_process_found_modules('test_requires', \@modules);
 			}
-		} else {
-			$self->_process_found_modules( 'test_requires', \@modules );
+			elsif ($self->develop && $self->xtest eq 'test_develop') {
+				$self->_process_found_modules('test_develop', \@modules);
+			}
+		}
+		else {
+			$self->_process_found_modules('test_requires', \@modules);
 		}
 	}
 
@@ -443,7 +448,7 @@ sub _process_found_modules {
 	my $require_type = shift;
 	my $modules_ref  = shift;
 
-	foreach my $module ( @{$modules_ref} ) {
+	foreach my $module (@{$modules_ref}) {
 
 		p $module       if $self->debug;
 		p $require_type if $self->debug;
@@ -452,50 +457,50 @@ sub _process_found_modules {
 		next if $module eq NONE;
 
 		# let's show every thing we can find infile
-		if ($self->format ne 'infile'){
+		if ($self->format ne 'infile') {
 
-		my $distribution_name = $self->distribution_name // 'm/t';
-		given ($module) {
-			when (/perl/sxm) {
+			my $distribution_name = $self->distribution_name // 'm/t';
+			given ($module) {
+				when (/perl/sxm) {
 
-				# ignore perl we will get it from minperl required
-				next;
-			}
-			when (/\A\Q$distribution_name\E/sxm) {
+					# ignore perl we will get it from minperl required
+					next;
+				}
+				when (/\A\Q$distribution_name\E/sxm) {
 
-				# don't include our own packages here
-				next;
-#				next if $self->format ne 'infile';
-			}
-			when (/^t::/sxm) {
+					# don't include our own packages here
+					next;
+				}
+				when (/^t::/sxm) {
 
-				# don't include our own test packages here
-				next;
-			}
+					# don't include our own test packages here
+					next;
+				}
 
-			when (/Mojo/sxm) {
-				if ( $self->experimental ) {
-					if ( $self->_check_mojo_core( $module, $require_type ) ) {
-						if ( not $self->quiet ) {
-							print BRIGHT_BLACK;
-							say 'swapping out ' . $module . ' for Mojolicious';
-							print CLEAR;
+				when (/Mojo/sxm) {
+					if ($self->experimental) {
+						if ($self->_check_mojo_core($module, $require_type)) {
+							if (not $self->quiet) {
+								print BRIGHT_BLACK;
+								say 'swapping out ' . $module . ' for Mojolicious';
+								print CLEAR;
+							}
+							next;
 						}
-						next;
 					}
 				}
-			}
-			when (/^Padre/sxm) {
+				when (/^Padre/sxm) {
 
-				# mark all Padre core as just Padre, for plugins
-				$module = 'Padre';
+					# mark all Padre core as just Padre, for plugins
+					$module = 'Padre';
+				}
 			}
 		}
-		}
 
 		# lets keep track of how many times a module include is found
 		$self->{modules}{$module}{count} += 1;
-		push @{ $self->{modules}{$module}{infiles} }, [ $self->looking_infile(), $self->{found_version}{$module} // 0 ];
+		push @{$self->{modules}{$module}{infiles}},
+			[$self->looking_infile(), $self->{found_version}{$module} // 0];
 
 		# don't process already found modules
 		p $self->{modules}{$module}{location} if $self->debug;
@@ -503,7 +508,9 @@ sub _process_found_modules {
 		next if defined $self->{modules}{$module}{location};
 		p $module if $self->debug;
 
-		$self->_store_modules( $require_type, $module );
+		# add skip for infile as we don't need to get v-string from metacpan-api
+		$self->_store_modules($require_type, $module)
+			if $self->format ne 'infile';
 	}
 	return;
 }
@@ -519,11 +526,11 @@ sub _store_modules {
 
 	$self->_in_corelist($module)
 		if not defined $self->{modules}{$module}{corelist};
-	my $version = $self->get_module_version( $module, $require_type );
+	my $version = $self->get_module_version($module, $require_type);
 	given ($version) {
 
 		when ('!mcpan') {
-			$self->{$require_type}{$module} = colored( '!mcpan', 'magenta' )
+			$self->{$require_type}{$module} = colored('!mcpan', 'magenta')
 				if not $self->{skip_not_mcpan_stamp};
 			$self->{modules}{$module}{location} = $require_type;
 			$self->{modules}{$module}{version}  = '!mcpan';
@@ -535,30 +542,26 @@ sub _store_modules {
 			$self->{modules}{$module}{version} = $version if $self->core;
 		}
 		default {
-			if ( $self->{modules}{$module}{corelist} ) {
+			if ($self->{modules}{$module}{corelist}) {
 
-				$self->{$require_type}{$module} = colored( $version, 'bright_yellow' )
-					if ( $self->dual_life || $self->core );
+				$self->{$require_type}{$module} = colored($version, 'bright_yellow')
+					if ($self->dual_life || $self->core);
 				$self->{modules}{$module}{location} = $require_type
-					if ( $self->dual_life || $self->core );
+					if ($self->dual_life || $self->core);
 				$self->{modules}{$module}{version} = $version
-					if ( $self->dual_life || $self->core );
+					if ($self->dual_life || $self->core);
 				$self->{modules}{$module}{dual_life} = 1;
-
-
-#				$self->{$require_type}{$module} = colored( $version, 'bright_yellow' );
-#				$self->{modules}{$module}{version}   = $version;
-#				$self->{modules}{$module}{location}  = $require_type;
-#				$self->{modules}{$module}{dual_life} = 1;
-			} else {
-				$self->{$require_type}{$module} = colored( $version, 'yellow' );
-				$self->{$require_type}{$module} = colored( version->parse($version)->numify, 'yellow' )
+			}
+			else {
+				$self->{$require_type}{$module} = colored($version, 'yellow');
+				$self->{$require_type}{$module}
+					= colored(version->parse($version)->numify, 'yellow')
 					if $self->numify;
 
 				$self->{modules}{$module}{location} = $require_type;
 				$self->{modules}{$module}{version}  = $version;
 
-				$self->{$require_type}{$module} = colored( $version, 'bright_cyan' )
+				$self->{$require_type}{$module} = colored($version, 'bright_cyan')
 					if $self->{modules}{$module}{'distribution'};
 			}
 		}
@@ -578,14 +581,15 @@ sub _in_corelist {
 	#return 1 if defined $self->{modules}{$module}{corelist};
 
 	# hash with core modules to process regardless
-	my $ignore_core = { 'File::Path' => 1, 'Test::More' => 1, };
+	my $ignore_core = {'File::Path' => 1, 'Test::More' => 1,};
 
-	if ( !$ignore_core->{$module} ) {
+	if (!$ignore_core->{$module}) {
 
-		if ( Module::CoreList->first_release($module) ) {
+		if (Module::CoreList->first_release($module)) {
 			$self->{modules}{$module}{corelist} = 1;
 			return 1;
-		} else {
+		}
+		else {
 			$self->{modules}{$module}{corelist} = 0;
 			return 0;
 		}
@@ -602,7 +606,7 @@ sub remove_noisy_children {
 	my $required_ref = shift || return;
 	my @sorted_modules;
 
-	foreach my $module_name ( sort keys %{$required_ref} ) {
+	foreach my $module_name (sort keys %{$required_ref}) {
 		push @sorted_modules, $module_name;
 	}
 
@@ -613,12 +617,12 @@ sub remove_noisy_children {
 
 		# inc so we don't end up with parent eq child
 		$outer_index++;
-		foreach my $inner_index ( $outer_index .. $#sorted_modules ) {
+		foreach my $inner_index ($outer_index .. $#sorted_modules) {
 			my $child_name = $sorted_modules[$inner_index];
 
 			# we just caught an undef
 			next if not defined $child_name;
-			if ( $child_name =~ /^ $parent_name ::/x ) {
+			if ($child_name =~ /^ $parent_name ::/x) {
 
 				my $valied_seperation = 1;
 
@@ -628,12 +632,16 @@ sub remove_noisy_children {
 
 				# Checking for one degree of separation
 				# ie A::B -> A::B::C is ok but A::B::C::D is not
-				if ( $self->degree_separation( $parent_name, $child_name ) <= $valied_seperation ) {
+				if ($self->degree_separation($parent_name, $child_name)
+					<= $valied_seperation)
+				{
 
 					# Test for same version number
-					if ( colorstrip( $required_ref->{$parent_name} ) eq colorstrip( $required_ref->{$child_name} ) ) {
-						if ( not $self->quiet ) {
-							if ( $self->verbose ) {
+					if (colorstrip($required_ref->{$parent_name}) eq
+						colorstrip($required_ref->{$child_name}))
+					{
+						if (not $self->quiet) {
+							if ($self->verbose) {
 								print BRIGHT_BLACK;
 								say 'delete miscreant noisy child '
 									. $child_name . ' => '
@@ -645,10 +653,11 @@ sub remove_noisy_children {
 							delete $required_ref->{$child_name};
 							splice @sorted_modules, $inner_index, 1;
 
-							unless ( $self->{modules}{$parent_name} ){
-							$self->{modules}{$parent_name}{location} = 'expermental';
-							$self->{modules}{$parent_name}{version}  = $required_ref->{$parent_name};
-							$self->{modules}{$parent_name}{count} += 1;
+							unless ($self->{modules}{$parent_name}) {
+								$self->{modules}{$parent_name}{location} = 'expermental';
+								$self->{modules}{$parent_name}{version}
+									= $required_ref->{$parent_name};
+								$self->{modules}{$parent_name}{count} += 1;
 							}
 						};
 						p @sorted_modules if $self->debug;
@@ -656,13 +665,15 @@ sub remove_noisy_children {
 						# we need to redo as we just deleted a child
 						redo;
 
-					} else {
+					}
+					else {
 
 						# not my child so lets try the next one
 						next;
 					}
 				}
-			} else {
+			}
+			else {
 
 				# no more like the parent so lets start again
 				last;
@@ -679,7 +690,7 @@ sub remove_twins {
 	my $self = shift;
 	my $required_ref = shift || return;
 	my @sorted_modules;
-	foreach my $module_name ( sort keys %{$required_ref} ) {
+	foreach my $module_name (sort keys %{$required_ref}) {
 		push @sorted_modules, $module_name;
 	}
 
@@ -689,7 +700,7 @@ sub remove_twins {
 	return if $#sorted_modules == 0;
 
 	my $n = 0;
-	while ( $sorted_modules[$n] ) {
+	while ($sorted_modules[$n]) {
 
 		my $dum_name    = $sorted_modules[$n];
 		my $dum_parient = $dum_name;
@@ -697,7 +708,7 @@ sub remove_twins {
 
 		my $dee_parient;
 		my $dee_name;
-		if ( ( $n + 1 ) <= $#sorted_modules ) {
+		if (($n + 1) <= $#sorted_modules) {
 			$n++;
 			$dee_name    = $sorted_modules[$n];
 			$dee_parient = $dee_name;
@@ -705,19 +716,24 @@ sub remove_twins {
 		}
 
 		# Checking for same patient and score
-		if (   $dum_parient eq $dee_parient
-			&& $self->degree_separation( $dum_name, $dee_name ) == 0 )
+		if ( $dum_parient eq $dee_parient
+			&& $self->degree_separation($dum_name, $dee_name) == 0)
 		{
 
 			# Test for same version number
-			if ( $required_ref->{ $sorted_modules[ $n - 1 ] } eq $required_ref->{ $sorted_modules[$n] } ) {
-				if ( not $self->quiet ) {
-					if ( $self->verbose ) {
+			if ($required_ref->{$sorted_modules[$n - 1]} eq
+				$required_ref->{$sorted_modules[$n]})
+			{
+				if (not $self->quiet) {
+					if ($self->verbose) {
 						print BRIGHT_BLACK;
 
 						# say 'i have found twins';
-						print $dum_name . ' => ' . $required_ref->{ $sorted_modules[ $n - 1 ] };
-						print BRIGHT_BLACK ' <-twins-> ' . $dee_name . ' => ' . $required_ref->{ $sorted_modules[$n] };
+						print $dum_name . ' => '
+							. $required_ref->{$sorted_modules[$n - 1]};
+						print BRIGHT_BLACK ' <-twins-> '
+							. $dee_name . ' => '
+							. $required_ref->{$sorted_modules[$n]};
 						print CLEAR "\n";
 					}
 				}
@@ -727,11 +743,13 @@ sub remove_twins {
 
 				$version = $self->get_module_version($dum_parient);
 
-				if ( looks_like_number($version) ) {
+				if (looks_like_number($version)) {
 
 					#Check parent version against a twins version
-					if ( $version eq $required_ref->{ $sorted_modules[$n] } ) {
-						say $dum_parient . ' -> ' . $version . ' is the parent of these twins'
+					if ($version eq $required_ref->{$sorted_modules[$n]}) {
+						say $dum_parient . ' -> '
+							. $version
+							. ' is the parent of these twins'
 							if $self->verbose;
 						$required_ref->{$dum_parient} = $version;
 						$self->_set_found_twins(1);
@@ -739,7 +757,7 @@ sub remove_twins {
 				}
 			}
 		}
-		$n++ if ( $n == $#sorted_modules );
+		$n++ if ($n == $#sorted_modules);
 	}
 	return;
 }
@@ -756,14 +774,14 @@ sub _check_mojo_core {
 	my $mojo_module_ver;
 	state $mojo_ver;
 
-	if ( not defined $mojo_ver ) {
+	if (not defined $mojo_ver) {
 		$mojo_ver = $self->get_module_version('Mojolicious');
 		p $mojo_ver if $self->debug;
 	}
 
 	$mojo_module_ver = $self->get_module_version($mojo_module);
 
-	if ( $self->verbose ) {
+	if ($self->verbose) {
 		print BRIGHT_BLACK;
 
 		#say 'looks like we found another mojo core module';
@@ -771,12 +789,14 @@ sub _check_mojo_core {
 		print CLEAR;
 	}
 
-	if ( $mojo_ver == $mojo_module_ver ) {
-		$self->{$require_type}{'Mojolicious'} = colored( $mojo_module_ver, 'bright_blue' )
+	if ($mojo_ver == $mojo_module_ver) {
+		$self->{$require_type}{'Mojolicious'}
+			= colored($mojo_module_ver, 'bright_blue')
 			if !$self->{modules}{'Mojolicious'};
 		$self->{modules}{'Mojolicious'}{location} = $require_type;
 		return 1;
-	} else {
+	}
+	else {
 		return 0;
 	}
 }
@@ -796,8 +816,8 @@ sub get_module_version {
 	try {
 		$module =~ s/::/-/g;
 
-		# quick n dirty, get version number if module is classed as a distribution in metacpan
-		my $mod = $self->mcpan->release( distribution => $module );
+# quick n dirty, get version number if module is classed as a distribution in metacpan
+		my $mod = $self->mcpan->release(distribution => $module);
 
 		#p $mod;
 		$cpan_version = $mod->{version_numified};
@@ -813,23 +833,22 @@ sub get_module_version {
 			$dist = $mcpan_module_info->{distribution};
 
 			# mark all perl core modules with either 'core' or '0'
-			if ( $dist eq 'perl' ) {
+			if ($dist eq 'perl') {
 				$cpan_version = 'core';
 				$found        = 1;
 			}
 		};
-		if ( $found == 0 ) {
+		if ($found == 0) {
 			try {
-				my $mod = $self->mcpan->release( distribution => $dist );
+				my $mod = $self->mcpan->release(distribution => $dist);
 
 				# This is where we add a dist version to a knackered module
 				$cpan_version                           = $mod->{version_numified};
 				$found                                  = 1;
 				$self->{modules}{$module}{distribution} = $dist;
-				$self->mod_in_dist(
-					$dist, $module, $require_type,
-					$mod->{version_numified}
-				) if $require_type;
+				$self->mod_in_dist($dist, $module, $require_type,
+					$mod->{version_numified})
+					if $require_type;
 			}
 		}
 	}
@@ -839,12 +858,14 @@ sub get_module_version {
 	};
 
 	# scientific numbers in a version string, O what fun.
-	if ( $cpan_version =~ m/\d+e/ ) {
+	if ($cpan_version =~ m/\d+e/) {
 
 		# a bit of de crappy-flying
 		# catch Test::Kwalitee::Extra 6e-06
 		print BRIGHT_BLACK;
-		say $module . ' Unique Release Sequence Indicator NOT! -> ' . $cpan_version
+		say $module
+			. ' Unique Release Sequence Indicator NOT! -> '
+			. $cpan_version
 			if $self->verbose >= 1;
 		print CLEAR;
 		$cpan_version = version->parse($cpan_version)->numify;
@@ -864,20 +885,20 @@ sub mod_in_dist {
 	my $version      = shift;
 
 	$dist =~ s/-/::/g;
-	if ( $module =~ /$dist/ ) {
+	if ($module =~ /$dist/) {
 
 		print BRIGHT_BLACK;
 		say "module - $module  -> in dist - $dist" if $self->verbose >= 1;
 		print CLEAR;
 
 		# add dist to output hash so we can get rind of cruff later
-		if ( $self->experimental ) {
+		if ($self->experimental) {
 
-			$self->{$require_type}{$dist} = colored( $version, 'bright_cyan' )
+			$self->{$require_type}{$dist} = colored($version, 'bright_cyan')
 				if not defined $self->{modules}{$module}{location};
 		}
 
-		$self->{$require_type}{$module} = colored( $version, 'bright_cyan' )
+		$self->{$require_type}{$module} = colored($version, 'bright_cyan')
 			if not defined $self->{modules}{$module}{location};
 	}
 
@@ -894,8 +915,8 @@ sub degree_separation {
 	my $child  = shift;
 
 	# Use of implicit split to @_ is deprecated
-	my $parent_score = @{ [ split /::/, $parent ] };
-	my $child_score  = @{ [ split /::/, $child ] };
+	my $parent_score = @{[split /::/, $parent]};
+	my $child_score  = @{[split /::/, $child]};
 	warn 'parent - ' . $parent . ' score - ' . $parent_score if $self->debug;
 	warn 'child - ' . $child . ' score - ' . $child_score    if $self->debug;
 
@@ -912,7 +933,7 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -920,7 +941,7 @@ App::Midgen - Check B<requires> & B<test_requires> of your package for CPAN incl
 
 =head1 VERSION
 
-This document describes App::Midgen version: 0.27_09
+This document describes App::Midgen version: 0.27_11
 
 =head1 SYNOPSIS
 
@@ -1069,7 +1090,7 @@ Oliver Gorwits E<lt>oliver@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright E<copy> 2013 the App:Midgen L</AUTHOR> and L</CONTRIBUTORS>
+Copyright E<copy> 2013-2014 the App:Midgen L</AUTHOR> and L</CONTRIBUTORS>
  as listed above.
 
 
